pub struct ZcosmicOutputConfigurationV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
Output configuration extension object
Extension to zwlr_output_configuration_v1.
Adds additional parameters to be tested/applyed via the original zwlr_output_configuration_v1.
See also the Request enum for this interface.
Implementations
Sourceimpl ZcosmicOutputConfigurationV1
impl ZcosmicOutputConfigurationV1
Sourcepub fn finished(&self)
pub fn finished(&self)
the configuration was used
This event indicates that the configuration is no longer available.
This usually happens when the original configuration was cancelled, suceeded or failed.
Upon receiving this event, the client should destroy this object.
The configration object becomes inert and any requests other than destroy will be ignored.